The ``config`` folder contains configuration files which customize default **PyAutoLens**.

Folders
-------

- ``priors``: Configs defining default priors assumed on every lens model component and set of parameters.
- ``visualize``: Configs defining what images are output by a lens model fit.

Files
-----

- ``general.yaml``: Customizes general **PyAutoLens** settings.
- ``non-linear.yaml``: Configs for default non-linear search (e.g. MCMC, nested sampling) settings.
- ``logging.yaml``: Customizes the logging behaviour of **PyAutoLens**.
- ``notation.yaml``: Configs defining labels and formatting of model parameters when used for visualization.
